bat API documentation

# bat

Black-box Adversarial Toolbox (BAT) is a python library for Distrubuted Black-box Attacks against Deep Learning Cloud Services.

## bat.apis

Supported Cloud APIs:

- DeepAPI
- Google Cloud Vision
- Imagga

## bat.attacks

Local Search:

- SimBA Attack (Guo et al., 2019)
- Square Attack (Andriushchenko et al., 2020)

Gradient Estimation:

- Bandits Attack (Ilyas et al., 2019)

## bat.utils

This module implements utility functions.

View Source

     1r'''
     2Black-box Adversarial Toolbox (BAT) is a python library for **Distrubuted Black-box Attacks** against Deep Learning Cloud Services.
     3
     4## bat.apis
     5
     6Supported Cloud APIs:
     7
     8- DeepAPI
     9- Google Cloud Vision
    10- Imagga
    11
    12## bat.attacks
    13
    14Local Search:
    15
    16- SimBA Attack [(Guo et al., 2019)](https://arxiv.org/abs/1905.07121)
    17- Square Attack [(Andriushchenko et al., 2020)](https://arxiv.org/abs/1912.00049)
    18
    19Gradient Estimation:
    20
    21- Bandits Attack [(Ilyas et al., 2019)](https://arxiv.org/abs/1807.07978)
    22
    23## bat.utils
    24
    25This module implements utility functions.
    26
    27'''
    28
    29# Project Imports
    30from bat import apis
    31from bat import attacks
    32
    33# Semantic Version
    34__version__ = "0.1.0"